@@ -345,8 +345,6 @@ wchar_t* nt_read_thread_title(nt_board_handle h_board,
 		free(outp);
 		return NULL;
 	}
-	//nt_thread_children_free(threadp);
-	//threadp->num_res = 0;
 	if(!feof(fp_src)){
 		s_src[0] = '\0';
 		if(!fgets(s_src, S_SIZE, fp_src)){
@@ -406,7 +404,7 @@ BOOL nt_read_board(nt_2ch_selected_item_handle h_select)
 		return FALSE;
 	
 	boardp = selectp->selected_boardp;
-	fwprintf(stderr, L"%ls\n", boardp->name);
+	//fwprintf(stderr, L"%ls\n", boardp->name);
 	h_mutex = nt_board_get_mutex(&boardp->handle);
 	if(!h_mutex)
 		return FALSE;
@@ -919,6 +917,7 @@ int nt_read_board_list(nt_link_tp selitem_list)
 			nt_pthread_release_ref(h_pthread);
 			nt_2ch_selected_item_release_ref(h_select);
 		}else{
+			nt_pthread_release_ref(h_pthread);
 			num_success++;
 		}
 #endif
@@ -956,7 +955,7 @@ BOOL nt_set_sel_item(nt_2ch_model_handle h_model,
 			nt_2ch_selected_item_handle *h_sel_itemp, 
 			nt_searched_thread_handle h_searched_thread, const wchar_t** errorpp)
 {
-	const wchar_t *board_name, *dat_name;
+	const wchar_t *board_name, *dat_name, *title;
 	nt_category_handle h_category;
 	nt_board_handle h_board;
 	nt_thread_handle h_thread;
@@ -973,6 +972,7 @@ BOOL nt_set_sel_item(nt_2ch_model_handle h_model,
 	assert(board_name);
 	
 	dat_name = nt_searched_thread_get_dat_name(h_searched_thread);
+	title = nt_searched_thread_get_title(h_searched_thread);
 	
 	h_board = nt_get_board_by_name(
 			h_model, board_name, &h_category);
@@ -981,7 +981,6 @@ BOOL nt_set_sel_item(nt_2ch_model_handle h_model,
 		nt_2ch_selected_item_release_ref(h_sel_item);
 		return FALSE;
 	}
-	
 	nt_set_selected_board(h_sel_item, h_category, h_board);
 	
 	
@@ -1008,8 +1007,13 @@ BOOL nt_set_sel_item(nt_2ch_model_handle h_model,
 	}
 	h_thread = nt_get_thread_by_dat_name(h_board, dat_name);
 	if(!h_thread){
-		*errorpp = L"スレッド情報が見つかりませんでした";
-		goto ERROR_TRAP;
+		if(!title)
+			title = L"Dummy";
+		h_thread = nt_thread_dummy_alloc(title, dat_name, 0);
+		if(!h_thread){
+			*errorpp = L"スレッド情報が見つかりませんでした";
+			goto ERROR_TRAP;
+		}
 	}
 	
 	nt_set_selected_thread(h_sel_item, h_thread);
