@@ -19,19 +19,27 @@
 #define _SEARCH_2CH_H_
 
 
-typedef struct tag_nt_searched_thread_t *nt_searched_thread_tp;
-typedef struct tag_nt_searched_thread_t{
-	wchar_t *board_name;
-	wchar_t *dat_name;
-	wchar_t *title;
-}nt_searched_thread_t;
+typedef struct tag_nt_searched_thread_handle *nt_searched_thread_handle;
+typedef struct tag_nt_searched_thread_handle{
+	int chk_sum;
+}nt_searched_thread_handle_t;
+
+extern nt_searched_thread_handle nt_searched_thread_alloc(
+		const wchar_t *board_name,const wchar_t *dat_name,
+		const wchar_t *title);
+extern int nt_searched_thread_add_ref(nt_searched_thread_handle h_searched_thread);
+extern int nt_searched_thread_release_ref(nt_searched_thread_handle h_searched_thread);
+
+extern const wchar_t* nt_searched_thread_get_board_name(
+			nt_searched_thread_handle handle);
+extern const wchar_t* nt_searched_thread_get_dat_name(
+			nt_searched_thread_handle handle);
+extern const wchar_t* nt_searched_thread_get_title(
+			nt_searched_thread_handle handle);
 
 extern BOOL nt_get_search_text(const char *in_text, char** out_text);
-extern nt_link_tp nt_search_all_board(nt_2ch_model_tp modelp, 
+extern nt_link_tp nt_search_all_board(nt_2ch_model_handle h_model, 
 			const char *search_text, const wchar_t **error_msg);
-extern void free_searched_thread(void *ptr);
-
-
 
 
 #endif /* _SEARCH_2CH_H_ */
