@@ -27,13 +27,21 @@ extern char USR_LOG_DB_PATH[];
 extern char USR_FAVORITE_BOARD_FILE_PATH[];
 extern char USR_FAVORITE_GRP_FILE_PATH[];
 extern char USR_FAVORITE_THREAD_FILE_PATH[];
+extern char *RFC2898_SALT;
+extern int  RFC2898_ITERATION;
+extern char *AES256_PASS;
+extern char *NCE_AUTH_URL;
+extern char *NCE_ID;
+extern char *NCE_PASS;
 
 extern int FORCE_REFRESH;
 extern int THREAD_SORT_TYPE; 
 extern int INIT_DISP_STATE; 
-extern int NT_MAINLOOP_POOLING_INTERVAL;
+extern int NT_MAINLOOP_POLLING_INTERVAL;
 extern int NT_PTHREAD_POOL_SIZE;
 extern int NT_PTHREAD_POOL_QUEUE_SIZE;
+extern int NT_AUTO_UPDATE_INTERVAL;
+extern int NT_AUTO_SCROLL_INTERVAL;
 
 extern char EDITOR_CMD[]; 
 extern char *MARU_ID;
@@ -65,6 +73,7 @@ extern char *MARU_PW;
 #define NT_KEY_COMMAND2 '/' 
 #define NT_KEY_COMMAND3 '?'
 #define NT_KEY_CMD_BOARD_UPDATE (65536 + 1)
+#define NT_KEY_CMD_AUTO_SCROLL (65536 + 2)
 
 #define NT_COMMAND1_WRITE_MSG_1 "write"
 #define NT_COMMAND1_WRITE_MSG_2 "w"
@@ -88,8 +97,16 @@ extern char *MARU_PW;
 #define NT_COMMAND1_SEARCH_2 "se"
 #define NT_COMMAND1_FAVORITE_1 "favorite"
 #define NT_COMMAND1_FAVORITE_2 "f"
+#define NT_COMMAND1_AUTOSCROLL_1 "autoscroll"
+#define NT_COMMAND1_AUTOSCROLL_2 "a"
+#define NT_COMMAND1_UPLOAD_1 "upload"
+#define NT_COMMAND1_UPLOAD_BOARD1 "board"
+#define NT_COMMAND1_UPLOAD_BOARD2 "b"
+#define NT_COMMAND1_UPLOAD_THREAD1 "thread"
+#define NT_COMMAND1_UPLOAD_THREAD2 "t"
 
 extern int set_option(int argc, char* argv[]);
 
+extern void nt_env_free();
 
 #endif /*  _ENV_H_ */
