@@ -20,6 +20,7 @@
 
 
 #define NT_MUTEX_ROOT_NAME_FILE (L"file:")
+#define NT_MUTEX_ROOT_NAME_NET (L"net:")
 
 typedef struct tag_nt_mutex_handle{
 	int chk_sum;
@@ -33,6 +34,7 @@ extern BOOL nt_mutex_lock(nt_mutex_handle handle);
 extern BOOL nt_mutex_unlock(nt_mutex_handle handle);
 extern nt_mutex_handle nt_mutex_get_one_time_handle(const wchar_t *moniker);
 extern BOOL nt_mutex_add_moniker(nt_mutex_handle handle, const wchar_t *moniker);
+extern BOOL nt_mutex_add_mbs_moniker(nt_mutex_handle handle, const char *moniker);
 
 #endif /* _NT_MUTEX_H_ */
 
