@@ -46,31 +46,49 @@ typedef struct tag_nt_stack_t{
 	nt_link_tp unlinkedp;
 } nt_stack_t;
 
-typedef struct tag_nt_queue_t *nt_queue_tp;
-typedef struct tag_nt_queue_t{
-	int num;
-	nt_link_tp linkp;
-} nt_queue_t;
-
 typedef struct tag_nt_enum_handle *nt_enum_handle;
 typedef struct tag_nt_enum_handle {
 	int chk_sum;
 }nt_enum_handle_t;
 
+typedef struct tag_nt_map_handle *nt_map_handle;
+typedef struct tag_nt_map_handle {
+	int chk_sum;
+}nt_map_handle_t;
+
+typedef struct tag_nt_queue_handle *nt_queue_handle;
+typedef struct tag_nt_queue_handle{
+	int chk_sum;
+} nt_queue_handle_t;
+
 #define nt_enum_release(a) nt_enum_unset((a))
 
+/* 
+ * nt_enum_handle nt_enum_set(nt_link_tp linkp)
+ * Set NULL to the linkp is accesptable and returns
+ * an empty enumerator object (not NULL).
+ * When you get a valid object, 
+ * you must free it by calling nt_enum_unset. */
 extern nt_enum_handle nt_enum_set(nt_link_tp linkp);
+
 extern void nt_enum_reset(nt_enum_handle handle);
 extern void nt_enum_unset(nt_enum_handle handle);
 extern void* nt_enum_fetch(nt_enum_handle handle);
 extern int nt_enum_get_count(nt_enum_handle handle);
+extern void nt_enum_set_free_func(nt_enum_handle handle, nt_memfree_fn free_func);
 
+extern nt_map_handle nt_map_alloc();
+extern void nt_map_free(nt_map_handle handle, nt_memfree_fn value_free_func);
+extern BOOL nt_map_add_pair(nt_map_handle handle, const wchar_t *key, void *value);
+extern void* nt_map_find(nt_map_handle handle, const wchar_t *key);
+extern void* nt_map_remove(nt_map_handle handle, const wchar_t *key);
+extern int nt_map_get_count(nt_enum_handle handle);
 
-extern nt_queue_tp nt_queue_alloc();
-extern void nt_queue_free(nt_queue_tp que, nt_memfree_fn free_func);
-extern BOOL nt_queue_push(nt_queue_tp ptr, void* data);
-extern void* nt_queue_shift(nt_queue_tp ptr);
-extern int nt_queue_get_count(nt_queue_tp ptr);
+extern nt_queue_handle nt_queue_alloc();
+extern void nt_queue_free(nt_queue_handle h_que, nt_memfree_fn free_func);
+extern BOOL nt_queue_push(nt_queue_handle h_que, void* data);
+extern void* nt_queue_shift(nt_queue_handle h_que);
+extern int nt_queue_get_count(nt_queue_handle h_que);
 
 extern void* nt_stack_push(nt_stack_tp stackp, void* data);
 extern void* nt_stack_peek(nt_stack_tp stackp);
@@ -109,6 +127,13 @@ typedef struct tag_nt_key_value_t{
 	char *value;
 }nt_key_value_t;
 
+typedef struct tag_nt_w_key_value_t *nt_w_key_value_tp;
+typedef struct tag_nt_w_key_value_t{
+	wchar_t *key;
+	void *value;
+}nt_w_key_value_t;
+
 extern nt_key_value_tp nt_key_value_alloc(char *key, char *value);
+extern nt_w_key_value_tp nt_w_key_value_alloc(const wchar_t *key, void *value);
 
 #endif /* _NT_STD_T_H_ */
