@@ -21,7 +21,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <ncursesw/ncurses.h>
 #include <locale.h>
 #include <iconv.h>
 #include <netinet/in.h>
@@ -39,6 +38,8 @@
 #include "utils/nt_mutex.h"
 #include "utils/nt_pthread.h"
 #include "utils/nt_timer.h"
+#include "utils/base64.h"
+#include "utils/crypt.h"
 #include "usr/favorite_t.h"
 #include "_2ch/_2ch.h"
 #include "_2ch/maru_2ch.h"
@@ -46,13 +47,22 @@
 #include "ui/disp.h"
 #include "ui/disp_win.h"
 #include "ui/disp_string.h"
-
+#ifdef NT_CLOUD
+#include "cloud/nt_cloud.h"
+#endif
 #define S_SIZE 	(1024)
 
 static int draw_title(WINDOW *wp, const wchar_t *title, attr_t attr);
+#ifdef NT_CLOUD
+static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
+			nt_cloud_handle h_cloud,
+			nt_favorite_handle h_favorite, 
+			nt_favorite_grp_handle h_favorite_grp);
+#else
 static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 			nt_favorite_handle h_favorite, 
 			nt_favorite_grp_handle h_favorite_grp);
+#endif
 static void print_error(WINDOW *wp, const wchar_t *msg);
 
 static void _2ch_selected_item_free(void *ptr)
@@ -71,15 +81,20 @@ int main(int argc, char *argv[])
 	nt_favorite_grp_handle h_favorite_grp;
 	nt_link_tp text_linkp, text2_linkp;
 	const char *err_msg;
+#ifdef NT_CLOUD
+	nt_cloud_handle h_cloud;
+	h_cloud = NULL;
+#endif
+	err_msg = NULL;
 
+	setlocale(LC_ALL, "ja_JP.UTF-8");
+	
 	if(0 != set_option(argc, argv)){
 		return 1;
 	}
 
-
 	sleep(1);
 
-	setlocale(LC_ALL, "ja_JP.UTF-8");
 
 	usr_db_handle = nt_usr_db_init_lib(USR_LOG_DB_PATH);
 	if(!usr_db_handle){
@@ -108,6 +123,20 @@ int main(int argc, char *argv[])
 		goto ERROR_TRAP;
 	}
 	
+#ifdef NT_CLOUD
+	if(nt_crypt_lib_init(RFC2898_SALT, RFC2898_ITERATION, 
+			AES256_PASS, &err_msg)){
+		if(NCE_AUTH_URL && NCE_ID && NCE_PASS){
+			h_cloud = nt_cloud_init(NCE_AUTH_URL, NCE_ID, NCE_PASS);
+		}
+	}else{
+		if(err_msg){
+			fputs(err_msg, stderr);
+			sleep(1);
+		}
+	}
+#endif
+
 	if(!nt_2ch_model_init()){
 		fputs("Failed to read board menu data.\n", stderr);
 		goto ERROR_TRAP;
@@ -131,12 +160,26 @@ int main(int argc, char *argv[])
 		goto ERROR_TRAP;
 	}
 	
-	text_linkp = nt_read_text_file(USR_FAVORITE_BOARD_FILE_PATH);
+	text_linkp = NULL;
+#ifdef NT_CLOUD
+	if(h_cloud){
+		text_linkp = nt_cloud_download_file(h_cloud, "fb.txt");
+	}
+#endif
+	if(!text_linkp)
+		text_linkp = nt_read_text_file(USR_FAVORITE_BOARD_FILE_PATH);
 	if(text_linkp){
 		nt_favorite_load_boards(h_favorite, text_linkp);
 		nt_all_link_free(text_linkp, free);
 	}
-	text_linkp = nt_read_text_file(USR_FAVORITE_THREAD_FILE_PATH);
+	text_linkp = NULL;
+#ifdef NT_CLOUD
+	if(h_cloud){
+		text_linkp = nt_cloud_download_file(h_cloud, "ft.txt");
+	}
+#endif
+	if(!text_linkp)
+		text_linkp = nt_read_text_file(USR_FAVORITE_THREAD_FILE_PATH);
 	if(text_linkp){
 		nt_favorite_load_threads(h_favorite, h_favorite_grp, text_linkp);
 		nt_all_link_free(text_linkp, free);
@@ -145,7 +188,11 @@ int main(int argc, char *argv[])
 	cbreak();
 	noecho();
 
+#ifdef NT_CLOUD
+	if(DoLoop(scrp, usr_db_handle, h_cloud, h_favorite, h_favorite_grp))
+#else
 	if(DoLoop(scrp, usr_db_handle, h_favorite, h_favorite_grp))
+#endif
 		result = 0;
 
 	echo();
@@ -189,6 +236,12 @@ ERROR_TRAP:
 
 	nt_timer_lib_finish();
 	
+#ifdef NT_CLOUD
+	nt_crypt_lib_finish();
+	if(h_cloud)
+		nt_cloud_release_ref(h_cloud);
+#endif
+	nt_env_free();
 	return (result);
 }
 
@@ -206,9 +259,16 @@ static int auto_update_timer_func(int id)
 	return TIMER_ID_AUTO_UPDATE_NONE;
 }
 
+#ifdef NT_CLOUD
+static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
+		nt_cloud_handle h_cloud,
+		nt_favorite_handle h_favorite, 
+		nt_favorite_grp_handle h_favorite_grp)
+#else
 static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 		nt_favorite_handle h_favorite, 
 		nt_favorite_grp_handle h_favorite_grp)
+#endif
 {
 	int ch, state, num;
 	int disp_state, nresult;
@@ -220,7 +280,7 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 	char buf[256];
 	wchar_t title_buf[128];
 	wchar_t wch;
-	const wchar_t *title;
+	const wchar_t *title, *board_name;
 	const wchar_t *status_msg;
 	BOOL result = FALSE;
 	nt_write_data_handle h_write_data;
@@ -234,7 +294,7 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 	nt_favorite_thread_handle h_favorite_thread;
 	void *handle;
 	nt_pthread_result_t async_data;
-	nt_link_tp linkp;
+	nt_link_tp linkp, linkp2;
 	BOOL auto_scrolling;
 	nt_timer_handle h_timer_auto_update;
 	nt_timer_handle h_timer_auto_scroll;
@@ -294,10 +354,18 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 			state = disp_board_menu(bwinp, app_2ch_model, h_sel_items);
 			if(DISP_CMD(state)){
 				if(DISP_CMD(state) == DISP_CMD_ADD_FAVORITE){
+					board_name = nt_2ch_selected_item_get_board_name(h_sel_items);
 					h_favorite_board = nt_favorite_board_alloc(
-						h_favorite,
-						nt_2ch_selected_item_get_board_name(h_sel_items));
+						h_favorite, board_name);
 					if(h_favorite_board){
+#ifdef NT_CLOUD
+						linkp = nt_link_add_data(NULL, (void*)board_name);
+						if(linkp){
+							if(h_cloud)
+								nt_cloud_insert_lines_into_file(h_cloud, "fb.txt", linkp);
+							free(linkp);
+						}
+#endif
 						nt_favorite_board_release_ref(h_favorite_board);
 						//favorite_dump(h_favorite);
 					}
@@ -349,6 +417,14 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 						nt_2ch_selected_item_get_board_name(h_sel_items),
 						nt_2ch_selected_item_get_thread_title(h_sel_items));
 					if(h_favorite_thread){
+#ifdef NT_CLOUD
+						linkp = NULL;
+						if(nt_favorite_retrieve_thread(h_favorite_thread, &linkp)){
+							if(h_cloud)
+								nt_cloud_insert_lines_into_file(h_cloud, "ft.txt", linkp);
+							nt_all_link_free(linkp, free);
+						}
+#endif
 						nt_favorite_thread_release_ref(h_favorite_thread);
 						//favorite_dump(h_favorite);
 						status_msg = NT_INFO_ADD_FAVORITE_SUCCEEDED;
@@ -491,6 +567,7 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					continue;
 				}
 			}
+			keypad(stdscr, true);
 			status_msg = nt_write_data_get_status_msg(h_write_data);
 			wclear(scrp);
 			continue;
@@ -516,6 +593,7 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}
 				}
 			}
+			keypad(stdscr, true);
 			disp_state = DISP_STATE_RESLIST;
 			state = DISP_STATE_RESLIST;
 			ch = NT_KEY_NONE;
@@ -592,6 +670,16 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				if(DISP_CMD(state) == DISP_CMD_DEL_FAVORITE_BOARD){
 					if(nt_favorite_board_remove(handle)){
 						h_favorite_board = (nt_favorite_board_handle)handle;
+#ifdef NT_CLOUD
+						if(h_cloud){
+							linkp = nt_link_add_data(NULL, 
+									(void*)nt_favorite_board_get_name(h_favorite_board));
+							if(linkp){
+								nt_cloud_delete_lines_from_file(h_cloud, "fb.txt", linkp);
+								free(linkp);
+							}
+						}
+#endif
 						nt_favorite_board_release_ref(h_favorite_board);
 						status_msg = NT_INFO_DEL_FAVORITE_SUCCEEDED;
 					}else{
@@ -600,6 +688,15 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				}else if(DISP_CMD(state) == DISP_CMD_DEL_FAVORITE_THREAD){
 					if(nt_favorite_thread_remove(handle)){
 						h_favorite_thread = (nt_favorite_thread_handle)handle;
+#ifdef NT_CLOUD
+						if(h_cloud){
+							linkp = NULL;
+							if(nt_favorite_retrieve_thread(h_favorite_thread, &linkp)){
+								nt_cloud_delete_lines_from_file(h_cloud, "ft.txt", linkp);
+								nt_all_link_free(linkp, free);
+							}
+						}
+#endif
 						nt_favorite_thread_release_ref(h_favorite_thread);
 						status_msg = NT_INFO_DEL_FAVORITE_SUCCEEDED;
 					}else{
@@ -626,6 +723,35 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}
 					nt_searched_thread_release_ref(h_searched_thread);
 					h_searched_thread = NULL;
+#ifdef NT_CLOUD
+				}else if(h_cloud){
+					if(DISP_CMD(state) == DISP_CMD_UPLOAD_ALL ||
+							DISP_CMD(state) == DISP_CMD_UPLOAD_BOARDS){
+						status_msg = NT_ERR_MSG_UPLOAD_FAVORITE_FAILED;
+						linkp = nt_favorite_retrieve_boards(h_favorite);
+						if(linkp){
+							if(nt_cloud_upload_file(h_cloud, "fb.txt", linkp)){
+								status_msg = NT_INFO_UPLOAD_FAVORITE_SUCCEEDED;
+							}
+							nt_all_link_free(linkp, free);
+						}
+					}
+					if(DISP_CMD(state) == DISP_CMD_UPLOAD_ALL ||
+							DISP_CMD(state) == DISP_CMD_UPLOAD_THREADS){
+						if(nt_favorite_retrieve_threads(h_favorite, 
+								&linkp, &linkp2)){
+							if(linkp)
+								nt_all_link_free(linkp, free);
+							if(linkp2){
+								if(nt_cloud_upload_file(h_cloud, "ft.txt", linkp2)){
+									status_msg = NT_INFO_UPLOAD_FAVORITE_SUCCEEDED;
+								}
+								nt_all_link_free(linkp2, free);
+							}
+						}
+					}
+					disp_state = state = DISP_STATE_FAVORITE;
+#endif
 				}else{
 					disp_state = state = DISP_STATE_FAVORITE;
 				}
