@@ -40,6 +40,16 @@ nt_socket_tp nt_socket_init(int port, char *addr)
 	nt_socket_tp ptr = malloc(sizeof(nt_socket_t));
 	if(ptr == NULL)
 		return NULL;
+		
+	ptr->h_mutex = nt_mutex_get_one_time_handle(NT_MUTEX_ROOT_NAME_NET);
+	if(!ptr->h_mutex){
+		free(ptr);
+		return NULL;
+	}
+	if(!nt_mutex_add_mbs_moniker(ptr->h_mutex, addr)){
+		free(ptr);
+		return NULL;
+	}
 	
 	ptr->_sockaddr_in.sin_family = AF_INET;
 	ptr->_sockaddr_in.sin_port = htons(port);
@@ -68,8 +78,11 @@ int nt_socket_connect(nt_socket_tp socketp, char* data, int data_len)
 	if(sockfd == -1)
 		return -1;
 	len = sizeof(socketp->_sockaddr_in);
+	
+	nt_mutex_lock(socketp->h_mutex);
 	result = connect(sockfd, 
 			(struct sockaddr *)&(socketp->_sockaddr_in), len);
+	nt_mutex_unlock(socketp->h_mutex);
 	if(result == -1){
 		close(sockfd);
 		return -1;
