@@ -90,8 +90,6 @@ static nt_favorite_thread_tp get_thread(
 		nt_favorite_grp_tp grpp,
 		const wchar_t *board_name,
 		const wchar_t *dat_name);
-static BOOL nt_favorite_retrieve_thread(
-	nt_favorite_thread_handle h_thread, nt_link_tp *thread_list);
 static nt_favorite_thread_tp parse_favorite_thread(const wchar_t *source);
 
 const wchar_t* nt_favorite_board_get_name(
@@ -1278,7 +1276,8 @@ static nt_favorite_thread_tp parse_favorite_thread(const wchar_t *source)
 		free(board_name);
 		return NULL;
 	}
-	len = end - start;
+	//len = end - start;
+	len = wcslen(start);
 	title = nt_w_substr(start, 0, len);
 
 	threadp = malloc(sizeof(nt_favorite_thread_t));
@@ -1299,7 +1298,8 @@ static nt_favorite_thread_tp parse_favorite_thread(const wchar_t *source)
 	return threadp;
 }
 
-static BOOL nt_favorite_retrieve_thread(
+
+BOOL nt_favorite_retrieve_thread(
 	nt_favorite_thread_handle h_thread, nt_link_tp *thread_list)
 {
 	const wchar_t *dat_name, *board_name, *title;
